@@ -7,12 +7,14 @@ use serde::Serialize;
 
 use crate::deps::DepsMut;
 use crate::exports::make_dependencies;
-use crate::ibc::{IbcBasicResponse, IbcChannel};
+use crate::ibc::{
+    IbcBasicResponse, IbcChannelCloseMsg, IbcChannelConnectMsg, IbcChannelOpenMsg, IbcPacketAckMsg,
+    IbcPacketReceiveMsg, IbcPacketTimeoutMsg, IbcReceiveResponse,
+};
 use crate::memory::{consume_region, release_buffer, Region};
 use crate::results::ContractResult;
 use crate::serde::{from_slice, to_vec};
 use crate::types::Env;
-use crate::{IbcAcknowledgementWithPacket, IbcPacket, IbcReceiveResponse};
 
 // TODO: replace with https://doc.rust-lang.org/std/ops/trait.Try.html once stabilized
 macro_rules! r#try_into_contract_result {
@@ -33,7 +35,7 @@ macro_rules! r#try_into_contract_result {
 ///
 /// contract_fn does the protocol version negotiation during channel handshake phase
 pub fn do_ibc_channel_open<E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<(), E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelOpenMsg) -> Result<(), E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -46,7 +48,7 @@ where
 }
 
 fn _do_ibc_channel_open<E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<(), E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelOpenMsg) -> Result<(), E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<()>
@@ -57,7 +59,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcChannel = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcChannelOpenMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
@@ -67,7 +69,7 @@ where
 ///
 /// contract_fn is a callback when a IBC channel is established (after both sides agree in open)
 pub fn do_ibc_channel_connect<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelConnectMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -81,7 +83,7 @@ where
 }
 
 fn _do_ibc_channel_connect<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelConnectMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<IbcBasicResponse<C>>
@@ -93,7 +95,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcChannel = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcChannelConnectMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
@@ -103,7 +105,7 @@ where
 ///
 /// contract_fn is a callback when a IBC channel belonging to this contract is closed
 pub fn do_ibc_channel_close<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelCloseMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -117,7 +119,7 @@ where
 }
 
 fn _do_ibc_channel_close<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcChannel) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcChannelCloseMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<IbcBasicResponse<C>>
@@ -129,7 +131,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcChannel = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcChannelCloseMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
@@ -140,7 +142,7 @@ where
 /// contract_fn is called when this chain receives an IBC Packet on a channel belonging
 /// to this contract
 pub fn do_ibc_packet_receive<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcPacket) -> Result<IbcReceiveResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketReceiveMsg) -> Result<IbcReceiveResponse<C>, E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -154,7 +156,7 @@ where
 }
 
 fn _do_ibc_packet_receive<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcPacket) -> Result<IbcReceiveResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketReceiveMsg) -> Result<IbcReceiveResponse<C>, E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<IbcReceiveResponse<C>>
@@ -166,7 +168,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcPacket = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcPacketReceiveMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
@@ -177,11 +179,7 @@ where
 /// contract_fn is called when this chain receives an IBC Acknowledgement for a packet
 /// that this contract previously sent
 pub fn do_ibc_packet_ack<C, E>(
-    contract_fn: &dyn Fn(
-        DepsMut,
-        Env,
-        IbcAcknowledgementWithPacket,
-    ) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketAckMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -195,11 +193,7 @@ where
 }
 
 fn _do_ibc_packet_ack<C, E>(
-    contract_fn: &dyn Fn(
-        DepsMut,
-        Env,
-        IbcAcknowledgementWithPacket,
-    ) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketAckMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<IbcBasicResponse<C>>
@@ -211,7 +205,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcAcknowledgementWithPacket = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcPacketAckMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
@@ -223,7 +217,7 @@ where
 /// timedout and will never be relayed to the calling chain. This generally behaves
 /// like ick_ack_fn upon an acknowledgement containing an error.
 pub fn do_ibc_packet_timeout<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcPacket) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketTimeoutMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: u32,
     msg_ptr: u32,
 ) -> u32
@@ -237,7 +231,7 @@ where
 }
 
 fn _do_ibc_packet_timeout<C, E>(
-    contract_fn: &dyn Fn(DepsMut, Env, IbcPacket) -> Result<IbcBasicResponse<C>, E>,
+    contract_fn: &dyn Fn(DepsMut, Env, IbcPacketTimeoutMsg) -> Result<IbcBasicResponse<C>, E>,
     env_ptr: *mut Region,
     msg_ptr: *mut Region,
 ) -> ContractResult<IbcBasicResponse<C>>
@@ -249,7 +243,7 @@ where
     let msg: Vec<u8> = unsafe { consume_region(msg_ptr) };
 
     let env: Env = try_into_contract_result!(from_slice(&env));
-    let msg: IbcPacket = try_into_contract_result!(from_slice(&msg));
+    let msg: IbcPacketTimeoutMsg = try_into_contract_result!(from_slice(&msg));
 
     let mut deps = make_dependencies();
     contract_fn(deps.as_mut(), env, msg).into()
